%global base_name vfs
%global short_name commons-%{base_name}

%define repodir %{_javadir}/repository.jboss.com/apache-%{base_name}/%{version}-brew
%define repodirlib %{repodir}/lib
%define repodirres %{repodir}/resources
%define repodirsrc %{repodir}/src

%define with_maven 1
%define with_repolib 1

%global namedreltag -SNAPSHOT
%global namedversion %{version}%{?namedreltag}

Name:          apache-commons-vfs
Version:       2.0
Release:       %mkrel 1
Summary:       Commons Virtual File System
Group:         Development/Java
License:       ASL 2.0
Url:           http://commons.apache.org/%{base_name}/

# svn export -r 834424 http://svn.apache.org/repos/asf/commons/proper/vfs/trunk commons-vfs-2.0-src
# tar czf commons-vfs-2.0-src-svn.tar.gz commons-vfs-2.0-src

Source0:       commons-vfs-2.0-src-svn.tar.gz
Source1:       apache-commons-vfs-component-info.xml

# org.codehaus.mojo findbugs-maven-plugin 1.0.0
Patch0:        apache-commons-vfs-pom.patch
Patch1:        apache-commons-vfs-SmbFileObject.patch
# org.apache.commons commons-build-plugin
Patch2:        apache-commons-vfs-commons-build-plugin.patch

Patch3:        apache-commons-vfs-ant.patch

BuildRequires: ant
BuildRequires: ant-junit
BuildRequires: apache-commons-codec
BuildRequires: apache-commons-collections
BuildRequires: apache-commons-logging
BuildRequires: apache-commons-net
BuildRequires: fonts-ttf-liberation
BuildRequires: glassfish-jaf
BuildRequires: jackrabbit >= 1.5.7
BuildRequires: jakarta-commons-httpclient
BuildRequires: jakarta-oro
BuildRequires: javamail
BuildRequires: jcifs
BuildRequires: jdepend
BuildRequires: jdom
BuildRequires: jsch
BuildRequires: junit
BuildRequires: xml-commons-apis

BuildRequires: apache-commons-parent
#BuildRequires: commons-build-plugin
BuildRequires: maven
BuildRequires: maven-assembly-plugin
BuildRequires: maven-changes-plugin
BuildRequires: maven-checkstyle-plugin
BuildRequires: maven-javadoc-plugin
BuildRequires: maven-plugin-jxr
BuildRequires: maven-project-info-reports-plugin
BuildRequires: maven-site-plugin
BuildRequires: maven-source-plugin
BuildRequires: maven-surefire-plugin
BuildRequires: slf4j
BuildRequires: velocity

Requires:      apache-commons-codec
Requires:      apache-commons-collections
Requires:      apache-commons-compress
Requires:      apache-commons-logging
Requires:      apache-commons-net
Requires:      jakarta-commons-httpclient
Requires:      glassfish-jaf
Requires:      jackrabbit >= 1.5.7
Requires:      javamail
Requires:      jcifs
Requires:      jdom
Requires:      jsch

Requires:      java
Requires:      jpackage-utils
Requires(post): jpackage-utils
Requires(postun): jpackage-utils
BuildArch:     noarch

%description
Commons VFS provides a single API for accessing various
different file systems. It presents a uniform view of the
files from various different sources, such as the files on
local disk, on an HTTP server, or inside a Zip archive.
Some of the features of Commons VFS are:
* A single consistent API for accessing files of different
 types.
* Support for numerous file system types.
* Caching of file information. Caches information in-JVM,
 and optionally can cache remote file information on the
 local file system.
* Event delivery.
* Support for logical file systems made up of files from
 various different file systems.
* Utilities for integrating Commons VFS into applications,
 such as a VFS-aware ClassLoader and URLStreamHandlerFactory.
* A set of VFS-enabled Ant tasks.

%package javadoc
Summary:          Javadocs for %{name}
Group:            Development/Java
Requires:         jpackage-utils

%description javadoc
This package contains the API documentation for %{name}.

%package manual
Summary:        Documents for %{name}
Group:          Development/Java

%description manual
This package contains documents for %{name}.

%if %with_repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%setup -q -n %{short_name}-%{version}-src
%patch0 -b .sav0
%patch1 -b .sav1
%patch2 -p0
%patch3 -p1


perl -pi -e 's/\r$//g;' *.txt

%build

%if %with_maven

mvn-rpmbuild -Dmaven.test.failure.ignore=true install javadoc:aggregate

%else

# TODO

%endif

%install
[ %{buildroot} != / ] && rm -rf %{buildroot}

mkdir -p %{buildroot}%{_javadir}

install -m 644 core/target/%{short_name}-%{namedversion}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
install -m 644 examples/target/%{short_name}-examples-%{namedversion}.jar %{buildroot}%{_javadir}/%{name}-examples-%{version}.jar
install -m 644 sandbox/target/%{short_name}-sandbox-%{namedversion}.jar %{buildroot}%{_javadir}/%{name}-sandbox-%{version}.jar

(
  cd %{buildroot}%{_javadir}
  for jar in *-%{version}*; do
    ln -sf ${jar} `echo $jar| sed "s|apache-||g"`
  done
)

(
  cd %{buildroot}%{_javadir}
  ln -s %{name}-%{version}.jar jakarta-%{short_name}-%{version}.jar
  ln -s %{name}-examples-%{version}.jar jakarta-%{short_name}-examples-%{version}.jar
  ln -s %{name}-sandbox-%{version}.jar jakarta-%{short_name}-sandbox-%{version}.jar
)

(
  cd %{buildroot}%{_javadir}
  for jar in *-%{version}*; do
    ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`
  done
)

mkdir -p %{buildroot}%{_mavenpomdir}
install -m 644 pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{short_name}-project.pom
%add_maven_depmap JPP-%{short_name}-project.pom
install -m 644 core/pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{short_name}.pom
%add_to_maven_depmap %{short_name} %{short_name} %{version} JPP %{short_name}
%add_maven_depmap JPP-%{short_name}.pom %{short_name}.jar
install -m 644 examples/pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{short_name}-examples.pom
%add_maven_depmap JPP-%{short_name}-examples.pom %{short_name}-examples.jar
%add_to_maven_depmap %{short_name} %{short_name}-examples %{version} JPP %{short_name}-examples
install -m 644 sandbox/pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{short_name}-sandbox.pom
%add_maven_depmap JPP-%{short_name}-sandbox.pom %{short_name}-sandbox.jar
%add_to_maven_depmap %{short_name} %{short_name}-sandbox %{version} JPP %{short_name}-sandbox

mkdir -p %{buildroot}%{_javadocdir}/%{short_name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{short_name}

%if %with_repolib
mkdir -p %{buildroot}%{repodir}
mkdir -p %{buildroot}%{repodirlib}
install -m 644 %{SOURCE1} %{buildroot}%{repodir}/component-info.xml
tag=`echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
sed -i "s/@TAG@/$tag/g" %{buildroot}%{repodir}/component-info.xml
sed -i "s/@VERSION@/%{version}-brew/g" %{buildroot}%{repodir}/component-info.xml
mkdir -p %{buildroot}%{repodirsrc}
install -m 644 %{PATCH0} %{buildroot}%{repodirsrc}/
install -m 644 %{PATCH1} %{buildroot}%{repodirsrc}/
install -m 644 %{PATCH2} %{buildroot}%{repodirsrc}/
install -m 644 %{PATCH3} %{buildroot}%{repodirsrc}/
install -m 644 %{SOURCE0} %{buildroot}%{repodirsrc}/
cp -pr %{buildroot}%{_javadir}/%{name}-%{version}.jar %{buildroot}%{repodirlib}/%{short_name}.jar
%endif

%clean
[ %{buildroot} != / ] && rm -rf %{buildroot}

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%{_javadir}/%{name}-%{version}.jar
%{_javadir}/%{name}.jar
%{_javadir}/%{name}-examples-%{version}.jar
%{_javadir}/%{name}-examples.jar
%{_javadir}/%{name}-sandbox-%{version}.jar
%{_javadir}/%{name}-sandbox.jar
%{_javadir}/%{short_name}-%{version}.jar
%{_javadir}/%{short_name}.jar
%{_javadir}/%{short_name}-examples-%{version}.jar
%{_javadir}/%{short_name}-examples.jar
%{_javadir}/%{short_name}-sandbox-%{version}.jar
%{_javadir}/%{short_name}-sandbox.jar
%{_javadir}/jakarta-%{short_name}-%{version}.jar
%{_javadir}/jakarta-%{short_name}.jar
%{_javadir}/jakarta-%{short_name}-examples-%{version}.jar
%{_javadir}/jakarta-%{short_name}-examples.jar
%{_javadir}/jakarta-%{short_name}-sandbox-%{version}.jar
%{_javadir}/jakarta-%{short_name}-sandbox.jar
%{_mavenpomdir}/*
%{_mavendepmapfragdir}/%{name}
%doc LICENSE.txt NOTICE.txt

%files javadoc
%{_javadocdir}/%{short_name}

%if %with_repolib
%files repolib
%{repodir}/*
%endif


%changelog

* Wed Oct 05 2011 dmorgan <dmorgan> 2.0-1.mga2
+ Revision: 151883
- Fix groups
- Clean spec file

  + gil <gil>
    - edit spec file
    - imported package apache-commons-vfs

